<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class RTWWPGE_Widget_PDF extends Widget_Base {
	private $rtwwpge_stng;
	public function get_name() {
		return 'wts-pricetable';
	}

	public function get_title() {
		return esc_html__( 'PDF - Generator', 'rtwwpge-wordpress-pdf-generator-for-elementor' );
	}

	public function get_icon() {
		return 'eicon-document-file';
	}

    public function get_categories() {
		return [ 'basic' ];
	}


	protected function register_controls() {
		$this->start_controls_section(
			'section_title',
			[
				'label' => esc_html__( 'PDF Settings', 'rtwwpge-wordpress-pdf-generator-for-elementor' )
			]
		);

		$this->add_control(
			'rtwwpge_pdf_width',
			[
				'label' => esc_html__( 'PDF Button Width', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'placeholder' => esc_html__( 'Enter PDF Button Width', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
				'default' => 60,
			]
		);

		$this->add_control(
			'rtwwpge_pdf_height',
			[
				'label' => esc_html__( 'PDF Button Height', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'placeholder' => esc_html__( 'Enter PDF Button Height', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
				'default' => 60,
			]
		);

        $this->add_control(
		  'rtwwpge_pdf_image',
		  [
		     'label' => esc_html__( 'PDF Button Icon', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
		     'type' => Controls_Manager::MEDIA,
		     'default' => [
		        'url' => RTWWPGE_URL.'/public/images/pdf_icon.png',
		     ],
		  ]
		);

        $this->add_control(
			'pdf_class',
			[
				'label' => esc_html__( 'Exclude HTML Class', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'For multiple use commma', 'rtwwpge-wordpress-pdf-generator-for-elementor' )
			]
		);

        $this->add_control(
			'pdf_id',
			[
				'label' => esc_html__( 'Exclude HTML ID', 'rtwwpge-wordpress-pdf-generator-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'For multiple use commma', 'rtwwpge-wordpress-pdf-generator-for-elementor' )
			]
		);

        $this->end_controls_section();
	}

	protected function render() {
        $settings = $this->get_settings();
        $rtwwpge_basic_stng = get_option('rtwwpge_basic_setting_opt');
		if( !$rtwwpge_basic_stng )
		{
			$rtwwpge_basic_stng = array();
		}
		$rtwwpge_css_stng = get_option('rtwwpge_css_setting_opt');
		if( !$rtwwpge_css_stng )
		{
			$rtwwpge_css_stng = array();
		}
		$rtwwpge_header_stng = get_option('rtwwpge_header_setting_opt');
		if( !$rtwwpge_header_stng )
		{
			$rtwwpge_header_stng = array();
		}
		$rtwwpge_footer_stng = get_option('rtwwpge_footer_setting_opt');
		if( !$rtwwpge_footer_stng )
		{
			$rtwwpge_footer_stng = array();
		}
		$rtwwpge_watermark_stng = get_option('rtwwpge_watermark_setting_opt');
		if( !$rtwwpge_watermark_stng )
		{
			$rtwwpge_watermark_stng = array();
		}
		$this->rtwwpge_stng = array_merge($rtwwpge_basic_stng,$rtwwpge_css_stng,$rtwwpge_header_stng,$rtwwpge_footer_stng,$rtwwpge_watermark_stng);

		global $post;
		
		if(empty( $this->rtwwpge_stng['rtwwpge_post_type'] ) )
		{
			return;
		}
		if ( !array_key_exists( get_post_type(), $this->rtwwpge_stng['rtwwpge_post_type'] ) )
		{
			return;
		}
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) 
		{
			if( is_cart() )
			{
				if ( !isset($rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_cart']) )
				{
					return;
				}
				if (isset($rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_cart']) && $rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_cart'] == 0 )
				{
					return;
				}
			}
			if( is_shop() )
			{
				if ( !isset($rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_shop']) )
				{
					return;
				}
				if (isset($rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_shop']) && $rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_shop'] == 0 )
				{
					return;
				}
			}
			if( is_checkout() )
			{
				if ( !isset($rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_checkout']) )
				{
					return;
				}
				if (isset($rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_checkout']) && $rtwwpge_basic_stng['rtwwpge_show_pdf_btn']['on_checkout'] == 0 )
				{
					return;
				}
			}
		}
		$rtwwpge_img = wp_get_attachment_image_src( $settings['rtwwpge_pdf_image']['id'], 'full' );
	   	if( !$rtwwpge_img )
	   	{
			   $rtwwpge_img[0] = $settings['rtwwpge_pdf_image']['url'];
	   	}
	   	$rtwwpge_width = '50px';
	   	$rtwwpge_height = '50px';
	   	if( isset( $settings['rtwwpge_pdf_width'] ) && !empty( $settings['rtwwpge_pdf_width'] ) )
	   	{
	   		$rtwwpge_width = $settings['rtwwpge_pdf_width'];
	   	}
	   	if( isset( $settings['rtwwpge_pdf_height'] ) && !empty( $settings['rtwwpge_pdf_height'] ) )
	   	{
	   		$rtwwpge_height = $settings['rtwwpge_pdf_height'];
	   	}

	   	// CHECK PDF FILE EXIST FOR CACHING
	   	if (isset($this->rtwwpge_stng['rtwwpge_file_name'] ) && $this->rtwwpge_stng ['rtwwpge_file_name'] == 'rtwwpge_post_name') {
			$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' . $post->post_name . '.pdf';
		} 
		else {
			$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' .$post->ID. '.pdf';
		}

		$rtwwpge_is_cache = true;
	   	if( !file_exists( $rtwwpge_file_path ) ) {
			$rtwwpge_is_cache = false;
		}

		if (isset($_SERVER['HTTP_X_GT_LANG']) && !empty($_SERVER['HTTP_X_GT_LANG']))
		{
			if ($_SERVER['HTTP_X_GT_LANG'] == 'zh-cn')
			{
				$rtwwpge_lang_code = 'zh-CN';
			}
			else if ($_SERVER['HTTP_X_GT_LANG'] == 'zh-tw')
			{
				$rtwwpge_lang_code = 'zh-TW';
			}
			else {
				$rtwwpge_lang_code = $_SERVER['HTTP_X_GT_LANG'];
			}
			$rtwwpge_post_url = esc_url ( add_query_arg ( 'rtwwpge_generate_pdf', 'true', home_url($rtwwpge_lang_code.$_SERVER['REQUEST_URI']) ) );
		}
		else {
			$rtwwpge_post_url = esc_url ( add_query_arg ( 'rtwwpge_generate_pdf', 'true', get_permalink ( $post->ID ) ) );
		}
		
		$rtwwpge_html = '<div class="rtwwpge_main">
			<a target="_blank"
				class="rtwwpge_pdf_button"
				title="'.esc_attr__('Download PDF', 'rtwwpge-wordpress-pdf-generator-for-elementor').'"
				data-post_id="' .esc_attr($post->ID).'"
				data-post_url="'.$rtwwpge_post_url.'"
				data-pdf_cache="'.esc_attr($rtwwpge_is_cache).'"
				data-pdf_class="'.$settings['pdf_class'].'"
				data-pdf_id="'.$settings['pdf_id'].'">
				<img alt="'.esc_attr__('Download PDF',' rtwwpge-wordpress-pdf-generator-for-elementor').'" src="'.esc_attr($rtwwpge_img[0]).'" width="'.esc_attr($rtwwpge_width).'" height="'.esc_attr($rtwwpge_height).'">
			</a>
			<img src="'.RTWWPGE_URL.'/public/images/spinner.gif" class="rtwwpge_pdf_gif">
		</div>';
		
		//This variable $rtwwpge_html holds html
		echo $rtwwpge_html;
	}

}
?>
<?php
$rtwwpge_purchase_code_details = get_option( 'rtwwpge_verification_done', array() );
if (!empty($rtwwpge_purchase_code_details) && is_array($rtwwpge_purchase_code_details) && isset($rtwwpge_purchase_code_details['status']) && $rtwwpge_purchase_code_details['status'] == true && isset($rtwwpge_purchase_code_details['purchase_code']) && $rtwwpge_purchase_code_details['purchase_code'] != '' )
{
	Plugin::instance()->widgets_manager->register_widget_type( new RTWWPGE_Widget_PDF() );
}